@@ -73,6 +73,11 @@ BEGIN {
 
 }
 
+# Make sure that each print statement flushes standard output.
+# This avoid having to manually flush when printing strings that do not end
+# in a newline.
+STDOUT->autoflush(1);
+
 my $respect_build_path = 1;
 my $use_tor            = 0;
 my $outdir             = './';
@@ -213,7 +218,7 @@ if (not $cdata->load($buildinfo)) {
 
 if ($cdata->get_option('is_pgp_signed')) {
     print(
-        "$buildinfo containes a GPG signature which has NOT been validated\n");
+        "$buildinfo contains a GPG signature which has NOT been validated\n");
 } else {
     print "$buildinfo was unsigned\n";
 }
