@@ -34,6 +34,7 @@ use IO::File;
 use Digest::MD5;
 use Devscripts::Compression;
 use Dpkg::Control;
+use Dpkg::Path   qw(find_command);
 use Getopt::Long qw(:config bundling permute no_getopt_compat);
 use File::Basename;
 
@@ -50,9 +51,9 @@ my $modified_conf_msg;
 my $compression_re = compression_get_file_extension_regex();
 
 # use curl if installed, wget otherwise
-if (system("command -v curl >/dev/null 2>&1") == 0) {
+if (find_command('curl')) {
     $wget = "curl";
-} elsif (system("command -v wget >/dev/null 2>&1") == 0) {
+} elsif (find_command('wget')) {
     $wget = "wget";
 } else {
     die
